@@ -701,7 +701,7 @@ class Account(base.Base, authenticable.Authenticable):
         if self.type == Account.USER_TYPE:
             tokens.update(["base", "user"])
 
-        for role in self.roles_l:
+        for role in self.roles_s:
             tokens.update(role.tokens_a)
 
         if "*" in tokens: tokens = ["*"]
@@ -725,7 +725,7 @@ class Account(base.Base, authenticable.Authenticable):
         """
 
         views = []
-        for role in self.roles_l:
+        for role in self.roles_s:
             view_m = role.view_m(context = self)
             if not view_m: continue
             views.append(view_m)
@@ -746,7 +746,7 @@ class Account(base.Base, authenticable.Authenticable):
         """
 
         meta = dict(self.meta)
-        for role in self.roles_l:
+        for role in self.roles_s:
             if join:
                 self._join_m(role.meta_a, meta)
             else:
@@ -917,6 +917,11 @@ class Account(base.Base, authenticable.Authenticable):
             self.roles_l.remove(_role)
         self.save()
 
+    @appier.operation(name = "Fix Roles", level = 2)
+    def fix_children_s(self, name):
+        self.roles = [role for role in self.roles if role and hasattr(role, "tokens_a")]
+        self.save()
+
     @appier.link(name = "View Avatar", devel = True)
     def view_avatar_url(self, absolute = False):
         cls = self.__class__
@@ -962,6 +967,10 @@ class Account(base.Base, authenticable.Authenticable):
     def roles_l(self):
         return self.roles
 
+    @property
+    def roles_s(self):
+        return [role for role in self.roles_l if role and hasattr(role, "tokens_a")]
+
     def _set_session(self, unset = True, safes = [], method = "set"):
         cls = self.__class__
         if unset: cls._unset_account(safes = safes)
