@@ -271,13 +271,13 @@ class Event(base.Base):
         kafka_server = appier.conf("KAFKA_SERVER", "localhost:9092")
         client_id = appier.conf("KAFKA_PRODUCER_CLIENT_ID", None)
         compression_type = appier.conf("KAFKA_COMPRESSION_TYPE", None)
-        retries = appier.conf("KAFKA_RETRIES", 0)
-        batch_size = appier.conf("KAFKA_BATCH_SIZE", 16384)
-        linger_ms = appier.conf("KAFKA_LINGER", 0)
-        connections_max_idle_ms = appier.conf("KAFKA_CONNECTIONS_MAX_IDLE", 540000)
-        max_request_size = appier.conf("KAFKA_MAX_REQUEST_SIZE", 1048576)
-        retry_backoff_ms = appier.conf("KAFKA_RETRY_BACKOFF", 100)
-        request_timeout_ms = appier.conf("KAFKA_REQUEST_TIMEOUT", 30000)
+        retries = appier.conf("KAFKA_RETRIES", 0, cast = int)
+        batch_size = appier.conf("KAFKA_BATCH_SIZE", 16384, cast = int)
+        linger_ms = appier.conf("KAFKA_LINGER", 0, cast = int)
+        connections_max_idle_ms = appier.conf("KAFKA_CONNECTIONS_MAX_IDLE", 540000, cast = int)
+        max_request_size = appier.conf("KAFKA_MAX_REQUEST_SIZE", 1048576, cast = int)
+        retry_backoff_ms = appier.conf("KAFKA_RETRY_BACKOFF", 100, cast = int)
+        request_timeout_ms = appier.conf("KAFKA_REQUEST_TIMEOUT", 30000, cast = int)
 
         cls._kafka = kafka.KafkaProducer(
             bootstrap_servers = kafka_server,
