@@ -117,17 +117,21 @@ class Role(base.Base):
     def view_m(self, context = None):
         return self.view_
 
+    @property
+    def children_s(self):
+        return [child for child in self.children if child and hasattr(child, "tokens_a")]
+
     @property
     def tokens_a(self):
         tokens = set(self.tokens)
-        for child in self.children:
+        for child in self.children_s:
             tokens.update(child.tokens_a)
         return tokens
 
     @property
     def meta_a(self):
         meta = dict(self.meta)
-        for child in self.children:
+        for child in self.children_s:
             self._join_m(child.meta_a, meta)
         return meta
 
@@ -199,6 +203,11 @@ class Role(base.Base):
         self.children.remove(child)
         self.save()
 
+    @appier.operation(name = "Fix Children", level = 2)
+    def fix_children_s(self, name):
+        self.children = [child for child in self.children if child and hasattr(child, "tokens_a")]
+        self.save()
+
     @appier.view(name = "Accounts")
     def accounts_v(self, *args, **kwargs):
         from appier_extras.parts.admin.models import account
