@@ -159,6 +159,8 @@ class AdminPart(
         self.owner.admin_layout_static = "admin/layout.static.html.tpl"
         self.owner.admin_email_layout = "admin/email/layout.html.tpl"
 
+        self.owner.admin_email_account_new_link = True
+
         self.owner.lib_loaders["appier_extras"] = self._appier_extras_loader
         self.owner.lib_loaders["netius"] = self._netius_loader
         self.owner.lib_loaders["pconvert"] = self._pconvert_loader
@@ -231,6 +233,7 @@ class AdminPart(
             (("GET", "POST"), "/admin/operations/build_index_db", self.build_index_db),
             (("GET", "POST"), "/admin/operations/test_email", self.test_email),
             (("GET", "POST"), "/admin/operations/test_event", self.test_event),
+            (("GET", "POST"), "/admin/operations/update_counter", self.update_counter),
             (("GET", "POST"), "/admin/operations/set_date", self.set_date),
             (("GET",), "/admin/sessions", self.list_sessions),
             (("GET",), "/admin/sessions/empty", self.empty_sessions),
@@ -335,7 +338,7 @@ class AdminPart(
             # of failure the error is logged
             account = self.account_c.login_key(key)
         except Exception as exception:
-            self.logger.warn("Problem running key based login: %s" % exception)
+            self.logger.warning("Problem running key based login: %s" % exception)
             return
 
         # marks the current session as transient as we're going
@@ -412,6 +415,16 @@ class AdminPart(
             description = "Trigger test event",
             note = "All handlers for the event are going to be triggered"
         )
+        self.add_operation(
+            "update_counter", "admin.update_counter",
+            description = "Update or create counter",
+            parameters = (
+                ("Counter", "counter", str),
+                ("Value", "value", int)
+            ),
+            note = "Updating an internal counter is a very dangerous operation",
+            level = 3
+        )
         self.add_operation(
             "set_date", "admin.set_date",
             description = "Set date (created & modified)",
@@ -426,6 +439,7 @@ class AdminPart(
         self.remove_operation("build_index_db")
         self.remove_operation("test_email")
         self.remove_operation("test_event")
+        self.remove_operation("update_counter")
         self.remove_operation("set_date")
 
     def add_section(self, name):
@@ -1219,6 +1233,30 @@ class AdminPart(
             )
         )
 
+    @appier.ensure(token = "admin", context = "admin")
+    def update_counter(self):
+        counter = self.field("counter", mandatory = True)
+        value = self.field("value", cast = int, mandatory = True)
+        collection = self._counters()
+        value = collection.find_and_modify(
+            {
+                "_id" : counter
+            },
+            {
+                "$max" : {
+                    "seq" : value
+                }
+            },
+            new = True,
+            upsert = True
+        )
+        return self.redirect(
+            self.url_for(
+                "admin.operations",
+                message = "Counter '%s' updated" % counter
+            )
+        )
+
     @appier.ensure(token = "admin", context = "admin")
     def set_date(self):
         set_c = 0
